indexing

	description:

		"Write to some destination."

	library: "Gobo Eiffel Pipework Library"
	copyright: "Copyright (c) 2003, Simon Parker and others"
	license: "Eiffel Forum License v2 (see forum.txt)"
	date: "$Date: $"
	revision: "$Revision: $"


deferred class

	PW_DESTINATION_WRITER [INWARD]

inherit

	PW_WRITER [INWARD]

feature -- Initialization

	make is
			-- Create or reset the adapter.
		do
			if is_connected then
				disconnect
			end
		ensure then
			not_connected: not is_connected
		end

feature -- Status

	is_connected: BOOLEAN is
			-- Is the drain side connected to a writer?
		do
			Result := drain /= Void
		ensure
			drain_if_connected: is_connected implies drain /= Void
		end

feature -- Connection management

	drain: ANY
			-- Where we send our output.
			-- Redefine for more precise type.

	connect (outlet: like drain) is
			-- Establish a (new) drain.
			-- Disconnect first, if necessary.
		do
			if is_connected then
				disconnect
			end
			drain := outlet
		ensure
			drain_installed: drain = outlet
			connected: is_connected
		end

	disconnect is
			-- Flush myself,
			-- then disconnect from current drain.
		require
			connected: is_connected
		do
			flush_current
			drain := Void
		ensure
			disconnected: not is_connected
		end

	reconnect (outlet: like drain) is
			-- Disconnect, then connect.
		require
			connected: is_connected
		do
			disconnect
			connect (outlet)
		ensure
			is_connected: is_connected
		end


feature {NONE} -- For descendents only

	flush_current is
			-- Write any items buffered by this adapter
			-- By default, do nothing.
		do
		end

end
